summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopetecontact.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/kopetecontact.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopetecontact.h')
-rw-r--r--kopete/libkopete/kopetecontact.h45
1 files changed, 23 insertions, 22 deletions
diff --git a/kopete/libkopete/kopetecontact.h b/kopete/libkopete/kopetecontact.h
index 3cefbb2a..4f8454fc 100644
--- a/kopete/libkopete/kopetecontact.h
+++ b/kopete/libkopete/kopetecontact.h
@@ -51,28 +51,29 @@ typedef TQPtrList<Group> GroupList;
* This class abstracts a generic contact
* Use it for inserting contacts in the contact list for example.
*/
-class KOPETE_EXPORT Contact : public QObject
+class KOPETE_EXPORT Contact : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
Q_ENUMS( CanCreateFlags )
- Q_PROPERTY( TQString formattedName READ formattedName )
- Q_PROPERTY( TQString formattedIdleTime READ formattedIdleTime )
- Q_PROPERTY( bool isOnline READ isOnline )
- Q_PROPERTY( bool fileCapable READ isFileCapable WRITE setFileCapable )
- Q_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
- //Q_PROPERTY( bool isReachable READ isReachable )
- Q_PROPERTY( TQString contactId READ contactId )
- Q_PROPERTY( TQString icon READ icon WRITE setIcon )
- Q_PROPERTY( TQString toolTip READ toolTip )
- Q_PROPERTY( TQString nickName READ nickName WRITE setNickName )
- //Q_PROPERTY( unsigned long idleTime READ idleTime WRITE setIdleTime )
+ TQ_PROPERTY( TQString formattedName READ formattedName )
+ TQ_PROPERTY( TQString formattedIdleTime READ formattedIdleTime )
+ TQ_PROPERTY( bool isOnline READ isOnline )
+ TQ_PROPERTY( bool fileCapable READ isFileCapable WRITE setFileCapable )
+ TQ_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
+ //TQ_PROPERTY( bool isReachable READ isReachable )
+ TQ_PROPERTY( TQString contactId READ contactId )
+ TQ_PROPERTY( TQString icon READ icon WRITE setIcon )
+ TQ_PROPERTY( TQString toolTip READ toolTip )
+ TQ_PROPERTY( TQString nickName READ nickName WRITE setNickName )
+ //TQ_PROPERTY( unsigned long idleTime READ idleTime WRITE setIdleTime )
public:
/**
* \brief Create new contact.
*
* <b>The parent MetaContact must not be NULL</b>
*
* \note id is required to be unique per protocol and per account.
* Across those boundaries ids may occur multiple times.
@@ -81,13 +82,13 @@ public:
* value! Even if it may look like an ICQ UIN or an MSN passport,
* this is undefined and may change at any time!
*
* @param account is the parent account. this constructor automatically register the contact to the account
* @param id is the Contact's unique Id (mostly the user's login)
* @param parent is the parent @ref MetaContact this Contact is part of
* @param icon is an optional icon
*/
- Contact( Account *account, const TQString &id, MetaContact *parent,
- const TQString &icon = TQString::null );
+ Contact( Account *account, const TQString &id, MetaContact *tqparent,
+ const TQString &icon = TQString() );
~Contact();
@@ -203,7 +204,7 @@ public:
* @brief Get the online status of the contact
* @return the online status of the contact
*/
- OnlineStatus onlineStatus() const;
+ OnlineStatus onlinetqStatus() const;
/**
* \brief Set the contact's online status
@@ -217,7 +218,7 @@ public:
* which is displayed in showContextMenu (private). Protocols
* should use this to add protocol-specific actions to the
* popup menu. Kopete take care of the deletion of the action collection.
* Actions should have the collection as parent.
*
* @return Collection of menu items to be show on the context menu
* @todo if possible, try to use KXMLGUI
@@ -448,7 +449,7 @@ public slots:
*
* default implementation does nothing
*
- * @param changed is a bitmask of the @ref Changed enum which say why the call to this funtion is done.
+ * @param changed is a bittqmask of the @ref Changed enum which say why the call to this funtion is done.
*/
virtual void sync(unsigned int changed = 0xFF);
@@ -475,7 +476,7 @@ public slots:
* file size (such as over asocket
*/
virtual void sendFile( const KURL &sourceURL = KURL(),
- const TQString &fileName = TQString::null, uint fileSize = 0L );
+ const TQString &fileName = TQString(), uint fileSize = 0L );
private slots:
@@ -509,7 +510,7 @@ signals:
* The contact's online status changed
*/
void onlineStatusChanged( Kopete::Contact *contact,
- const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
+ const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldtqStatus );
/**
* The contact is about to be destroyed.
@@ -51,28 +51,29 @@ typedef TQPtrList<Group> GroupList;
* \brief Create new contact.
*
- * <b>The parent MetaContact must not be NULL</b>
+ * <b>The tqparent MetaContact must not be NULL</b>
*
* \note id is required to be unique per protocol and per account.
@@ -81,13 +82,13 @@ public:
* this is undefined and may change at any time!
*
- * @param account is the parent account. this constructor automatically register the contact to the account
+ * @param account is the tqparent account. this constructor automatically register the contact to the account
* @param id is the Contact's unique Id (mostly the user's login)
@@ -81,13 +82,13 @@ public:
* @param id is the Contact's unique Id (mostly the user's login)
- * @param parent is the parent @ref MetaContact this Contact is part of
+ * @param tqparent is the tqparent @ref MetaContact this Contact is part of
* @param icon is an optional icon
*/
@@ -217,7 +218,7 @@ public:
* should use this to add protocol-specific actions to the
* popup menu. Kopete take care of the deletion of the action collection.
- * Actions should have the collection as parent.
+ * Actions should have the collection as tqparent.
*
* @return Collection of menu items to be show on the context menu